function [h]=PlotData(MyPlotID,x,y,MyLineStyle,MyMarkerStyle,MyColor,MyFilling,MyXLabel,MyYLabel,MyTitle,MyLegend,MyLocation,MyXLim,MyYLim,MyXaxis,MyYaxis,MyXTicks,MyYTicks,MyFileName)

% Management of the size of the array of data to plot
if size(x) ~= size(y)
    display('Arrays must have same dimension');
    [ax bx] = size(x);
    [ay by] = size(y);
    display(['Size of x is : ' num2str(ax) 'x' num2str(bx)]);
    display(['Size of y is : ' num2str(ay) 'x' num2str(by)]);
end
[MyDim bloblo] = size(x);

if (MyDim == 1)| (bloblo == 1)          % it means that the x and y are unidimensional vectors
    Zf_plotdatavector2(MyPlotID,x,y,MyLineStyle,MyMarkerStyle,MyColor,MyFilling,MyXLabel,MyYLabel,MyTitle,MyLegend,MyLocation,MyXLim,MyYLim,MyXaxis,MyYaxis,MyXTicks,MyYTicks,MyFileName);
else        % Draw as many plot as lines in the array (if vector : one plot)
    for dim=1:MyDim
        xx = x(dim,:);
        yy = y(dim,:);
        if (MyDim == 1) & (ischar(MyLegend)==0)
            display('Error : legend of single plot must be a standard string or a void string');
        end
        if (MyDim > 1) & (iscell(MyLegend)==0)
            display('Error : legend of multiple plot must be a cell of strings');
        end
        if (MyDim > 1) & (iscell(MyLegend)==1) & (length(MyLegend) ~= MyDim)
            display('Error : legend cell of multiple plot must contain as many non-void strings as plots');
            display('Consider transposing the inputs data');
        end
        MyLegendSingle = MyLegend{dim};
        Zf_plotdatavector2(MyPlotID,xx,yy,MyLineStyle,MyMarkerStyle,MyColor,MyFilling,MyXLabel,MyYLabel,MyTitle,MyLegend,MyLocation,MyXLim,MyYLim,MyXaxis,MyYaxis,MyXTicks,MyYTicks,MyFileName);
    end
end

%%
function [h]=Zf_plotdatavector2(MyPlotID,x,y,MyLineStyle,MyMarkerStyle,MyColor,MyFilling,MyXLabel,MyYLabel,MyTitle,MyLegend,MyLocation,MyXLim,MyYLim,MyXaxis,MyYaxis,MyXTicks,MyYTicks,MyFileName)

% Author : Olivier Bonnefoy
% Version : Apr-27 2012, 15:21

figure(MyPlotID);

MyLabelFontSize = 13;                   % Label font size (for xlabel and ylabel)
MyAxisFontSize  = MyLabelFontSize;      % Axis font size (for title, legend and figures simultaneously)
MyMarkerSize    = 6.5;                  % Marker size
MyLineWidth     = 1.4;                  % Width of line

set(gca,'Box','on','FontSize',MyAxisFontSize);                                      % Size of figures/axes
left = 2.5;
bottom = 1.5;
width = 10;
height = 8.5;
set(gca, 'Units', 'centimeters', 'Position', [left,bottom,width,height]);                    

if strcmp(MyLineStyle,'')
    MyLineStyle='none';
end
if strcmp(MyMarkerStyle,'')
    MyMarkerStyle='none';
end

if ~strcmp(MyTitle,'')
    title(MyTitle);
end
if ~strcmp(MyXLabel,'')
    % Selection of Interpreter ('latex' if the label contains a formula between $ sign, 'none' otherwise)
    interpreter = 'none';
    for i=1:length(MyXLabel)
        if strcmp(MyXLabel(i),'$')
            interpreter = 'latex';
        end
    end
    xlabel(gca, MyXLabel, 'FontSize', MyLabelFontSize, 'Interpreter', interpreter)
    warning('off','MATLAB:handle_graphics:exceptions:SceneNode');           % Remove warning due to latex font
end
if ~strcmp(MyYLabel,'')
    % Selection of Interpreter ('latex' if the label contains a formula between $ sign, 'none' otherwise)
    interpreter = 'none';
    for i=1:length(MyYLabel)
        if strcmp(MyYLabel(i),'$')
            interpreter = 'latex';
        end
    end
    ylabel(gca, MyYLabel, 'FontSize', MyLabelFontSize, 'Interpreter', interpreter)
    warning('off','MATLAB:handle_graphics:exceptions:SceneNode');           % Remove warning due to latex font
end
if (numel(MyYLim) ~= 0)                     % Example of MyYLim : [-1 1] or []
    if isnumeric(MyYLim)
        ylim(MyYLim);
    end
end
if (numel(MyXLim) ~= 0)                     % Example of MyXLim : [-1 1] or []
    if isnumeric(MyXLim)
        xlim(MyXLim);
    end
end

hold on

if strcmp(MyLegend,'') ~= 1
    h=plot(x,y,'LineStyle',MyLineStyle,'DisplayName', MyLegend);
    legend('Box', 'off', 'Location','Best');
else
    h=plot(x,y,'LineStyle',MyLineStyle);
end 
set(h,'LineWidth',MyLineWidth);

% Management of Markers

MyMarkers = {'o','s','d','^','v','<','>','h','o','s','d','^','v','<','>','h','o','s','d','^','v','<','>','h','o','s','d','^','v','<','>','h','o','s','d','^','v','<','>','h','o','s','d','^','v','<','>','h','o','s','d','^','v','<','>','h','o','s','d','^','v','<','>','h','o','s','d','^','v','<','>','h'};
SizeFactor = [1   1   1   1   1   1   1   1   1   1   1   1   1   1   1   1   1   1   1   1   1   1   1   1];
if strcmp(MyMarkerStyle,'auto')
    MyMarkerStyle=MyMarkers{var_ID};
    MyMarkerSize = MyMarkerSize * SizeFactor(var_ID);
end
set(h,'Marker',MyMarkerStyle);
set(h,'MarkerSize',MyMarkerSize);

% Management of colors

MyColors = {'k','b','r','g','m','c','k','b','r','g','m','c','k','b','r','g','m','c','k','b','r','g','m','c','k','b','r','g','m','c','k','b','r','g','m','c','k','b','r','g','m','c','k','b','r','g','m','c','k','b','r','g','m','c','k','b','r','g','m','c','k','b','r','g','m','c','k','b','r','g','m','c'};

switch MyColor
    case 'auto'
        MyColor=MyColors{var_ID};               % For lines (if not 'auto', color is specified)
    case 'empty'
        display('Syntax error in plot function : color argument cannot be "empty"');
    case 'filled'
        display('Syntax error in plot function : color argument cannot be "filled"');
end
switch MyFilling
    case 'empty'
        MyMarkerFaceColor='w';
    case 'filled'
        MyMarkerFaceColor=MyColor;
    case 'auto'
        if mod(var_ID,2) == 0
            MyMarkerFaceColor='w';
        else
            MyMarkerFaceColor=MyColor;
        end
end
set(h,'Color',MyColor,'MarkerFaceColor',MyMarkerFaceColor,'MarkerEdgeColor',MyColor);

% Management of time stamping (for purpose of retrieval) + path name + FileName
% The figure creation date is written on each figure (bottom right, vertically oriented), as well as current directory.
% It is gray and must be magnified

xxx=findobj(gca,'Tag','Figure_ID');
%size(xxx)
if size(xxx) == [0 1]  
    hobj=text('Position',[1.0035 0.005 0],'String',[ ' Creation date = ' datestr(now) '... Path = ' pwd '... File name = ' MyFileName '.emf'],'Units','normalized','FontSize',2,'Color',[175 169 163]/256,'Rotation',90,'VerticalAlignment','top','HorizontalAlignment','left','Interpreter','none','Tag','Figure_ID');
else
    delete(xxx);
    hobj=text('Position',[1.0035 0.005 0],'String',[ ' Creation date = ' datestr(now) '... Path = ' pwd '... File name = ' MyFileName '.emf'],'Units','normalized','FontSize',2,'Color',[175 169 163]/256,'Rotation',90,'VerticalAlignment','top','HorizontalAlignment','left','Interpreter','none','Tag','Figure_ID');
end

if ~strcmp(MyXTicks,'auto')
    set(gca,'XTick',MyXTicks);
end
if ~strcmp(MyYTicks,'auto')
    set(gca,'XTick',MyYTicks);
end
set(gca,'XScale',MyXaxis);
set(gca,'YScale',MyYaxis);
set(gca,'layer','top');         % bring the axis to the top to stop stuff being plotted over the black edges and tick marks
set(gca,'TickDir','out');       % set the direction of the tick marks to point outwards

if strcmp(MyFileName,'') ~= 1
    print -r0 -dmeta Image
    NomdeFichier = strcat(MyFileName,'.emf');
    movefile('Image.emf',NomdeFichier);
end