% Author : Olivier Bonnefoy (bonnefoy@emse.fr)
% Version : Sept-33 2021

clc;
clear all;

%% Global plot parameters  

Plot_ID     = 1;                                % Integer associated with the plot
MyXLabel    = '$\textsf{Viscosity } \mu \textsf{ [Pa.s]}$';        % can be '' or a string (can use LaTeX formula like 'Shear \bf{rate} $\dot \gamma$' but pure text or pure formula preferred)
                                                                    % Reference example : '$\textsf{Viscosity } \mu \textsf{ [Pa.s]}$'                                                                
MyYLabel    = '$\textsf{Inertial number } I \textsf{ [-]}$';        % can be '' or a string (can use LaTeX formula like 'Shear \bf{rate} $\dot \gamma$' but pure text or pure formula preferred)
MyTitle     = 'Exprience A23';                 % can be '' or a string (can use LaTeX formula like 'Shear rate $\dot \gamma$' but pure text or pure formula preferred)
MyXLim      = [0 12];                           % can be [] or [xlow xhigh]
MyYLim      = [1e-2 1e3];                       % can be [] or [ylow yhigh]
MyXaxis     = 'linear';                         % 'linear' or 'log'
MyYaxis     = 'log';                            % 'linear' or 'log'
MyXTicks    = 'auto';                           % 'auto' or [] or [1 2 5 8 10]
MyYTicks    = 'auto';                           % 'auto' or [] or [1 2 5 8 10]
MyLocation  = 'NorthWest';                      % Location of Legend : 'North', 'South', 'East', 'West', 'SouthEast','NorthEast','SouthWest','NorthWest','NorthOutside', 'SouthOutside', 'EastOutside', 'WestOutside'
MyFileName  = 'Bidule';                         % can be '' or a string (without extension). Figures are saved as emf files, which are compatible with Word or Powerpoint

%% Curve n1 (Experimental data)

x1            = 0:10;                           
y1            = (x1+sin(x1)).^2;                
Myxdata       = x1;                             % Myxdata is a vector or an array
Myydata       = y1;                             % Myydata is a vector or an array (same size as Myxdata)

MyLineStyle   = '';                             % can be  '-'    '--'    ':'    '-.'   'none'   ''
MyMarkerStyle = 'o';                            % can be +,o,*,.,x,s,d,^,v,>,<,p,h,none ''. If it is 'auto', then the marker style is cycled through osd^v<>h
MyColor       = 'b';                            % can be y,m,c,r,g,b,w,k. If it is'auto', then the color is cycled through kbrgmyc
MyFilling     = 'filled';                       % can be 'empty' or 'filled' or 'auto' (alternatively empty and filled)
MyLegend      = 'Experimental';                 % can be '' or 'Temperature' or 'Shear rate $\dot \gamma$' for single plots
                                                % and must be {'Variable 1' 'Variable 2' 'Variable 3'} for multiple plots (can use LaTeX formula like 'Shear rate $\dot \gamma$' but pure text or pure formula preferred)
  
% Do not modify the following command line
Engine(Plot_ID,Myxdata,Myydata,MyLineStyle,MyMarkerStyle,MyColor,MyFilling,MyXLabel,MyYLabel,MyTitle,MyLegend,MyLocation,MyXLim,MyYLim,MyXaxis,MyYaxis,MyXTicks,MyYTicks,MyFileName);

%% Curve n2 (Hydrodynamic analytic model)

x2 = x1 + 0.5;
y2 = (x2+sin(x2)).^2;              
Myxdata       = x2;                             % Myxdata is a vector or an array
Myydata       = y2;                             % Myydata is a vector or an array (same size as Myxdata)

MyLineStyle   = '-';                            % can be  '-'    '--'    ':'    '-.'   'none'   ''
MyMarkerStyle = '';                             % can be +,o,*,.,x,s,d,^,v,>,<,p,h,none ''. If it is 'auto', then the marker style is cycled through osd^v<>h
MyColor       = 'k';                            % can be y,m,c,r,g,b,w,k. If it is'auto', then the color is cycled through kbrgmyc
MyFilling     = 'empty';                        % can be 'empty' or 'filled' or 'auto' (alternatively empty and filled)
MyLegend      = 'Model';                        % can be '' or 'Temperature' or 'Shear rate $\dot \gamma$' for single plots
                                                % and must be {'Variable 1' 'Variable 2' 'Variable 3'} for multiple plots (can use LaTeX formula like 'Shear rate $\dot \gamma$' but pure text or pure formula preferred)
                                                
% Do not modify the following command line
Engine(Plot_ID,Myxdata,Myydata,MyLineStyle,MyMarkerStyle,MyColor,MyFilling,MyXLabel,MyYLabel,MyTitle,MyLegend,MyLocation,MyXLim,MyYLim,MyXaxis,MyYaxis,MyXTicks,MyYTicks,MyFileName);

%% Curve n3 (linear interpolation)

[r slope offset] = regression(x1,y1);
iii = linspace(0,12);
jjj = offset+slope.*iii;
Myxdata       = iii;                            % Myxdata is a vector or an array
Myydata       = jjj;                            % Myydata is a vector or an array (same size as Myxdata)

MyLineStyle   = '-';                            % can be  '-'    '--'    ':'    '-.'   'none'   ''
MyMarkerStyle = '';                             % can be +,o,*,.,x,s,d,^,v,>,<,p,h,none ''. If it is 'auto', then the marker style is cycled through osd^v<>h
MyColor       = 'r';                            % can be y,m,c,r,g,b,w,k. If it is'auto', then the color is cycled through kbrgmyc
MyFilling     = 'empty';                        % can be 'empty' or 'filled' or 'auto' (alternatively empty and filled)
MyLegend      = 'Linear fit';                   % can be '' or 'Temperature' or 'Shear rate $\dot \gamma$' for single plots
                                                % and must be {'Variable 1' 'Variable 2' 'Variable 3'} for multiple plots (can use LaTeX formula like 'Shear rate $\dot \gamma$' but pure text or pure formula preferred)
                                                
% Do not modify the following command line
Engine(Plot_ID,Myxdata,Myydata,MyLineStyle,MyMarkerStyle,MyColor,MyFilling,MyXLabel,MyYLabel,MyTitle,MyLegend,MyLocation,MyXLim,MyYLim,MyXaxis,MyYaxis,MyXTicks,MyYTicks,MyFileName);

text(1.25,8,['I=a.\eta+b'],'FontSize',12,'Units','centimeters','Color','r');
text(1.25,7.25,['a=' sprintf('%01.2f',slope)],'FontSize',12,'Units','centimeters','Color','r');
text(1.25,6.5,['b=' sprintf('%01.2f',offset)],'FontSize',12,'Units','centimeters','Color','r');

